==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/update_subnet_ids_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubnetIdsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'site_id': 'str',
        'body': 'UpdateSubnetIdsRequestBody'
    }

    attribute_map = {
        'site_id': 'site_id',
        'body': 'body'
    }

    def __init__(self, site_id=None, body=None):
        """UpdateSubnetIdsRequest

        The model defined in huaweicloud sdk

        :param site_id: 站点ID。
        :type site_id: str
        :param body: Body of the UpdateSubnetIdsRequest
        :type body: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        
        

        self._site_id = None
        self._body = None
        self.discriminator = None

        self.site_id = site_id
        if body is not None:
            self.body = body

    @property
    def site_id(self):
        """Gets the site_id of this UpdateSubnetIdsRequest.

        站点ID。

        :return: The site_id of this UpdateSubnetIdsRequest.
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this UpdateSubnetIdsRequest.

        站点ID。

        :param site_id: The site_id of this UpdateSubnetIdsRequest.
        :type site_id: str
        """
        self._site_id = site_id

    @property
    def body(self):
        """Gets the body of this UpdateSubnetIdsRequest.

        :return: The body of this UpdateSubnetIdsRequest.
        :rtype: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateSubnetIdsRequest.

        :param body: The body of this UpdateSubnetIdsRequest.
        :type body: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubnetIdsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/update_subnet_ids_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubnetIdsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'site_id': 'str',
        'body': 'UpdateSubnetIdsRequestBody'
    }

    attribute_map = {
        'site_id': 'site_id',
        'body': 'body'
    }

    def __init__(self, site_id=None, body=None):
        r"""UpdateSubnetIdsRequest

        The model defined in huaweicloud sdk

        :param site_id: 站点ID。
        :type site_id: str
        :param body: Body of the UpdateSubnetIdsRequest
        :type body: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        
        

        self._site_id = None
        self._body = None
        self.discriminator = None

        self.site_id = site_id
        if body is not None:
            self.body = body

    @property
    def site_id(self):
        r"""Gets the site_id of this UpdateSubnetIdsRequest.

        站点ID。

        :return: The site_id of this UpdateSubnetIdsRequest.
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        r"""Sets the site_id of this UpdateSubnetIdsRequest.

        站点ID。

        :param site_id: The site_id of this UpdateSubnetIdsRequest.
        :type site_id: str
        """
        self._site_id = site_id

    @property
    def body(self):
        r"""Gets the body of this UpdateSubnetIdsRequest.

        :return: The body of this UpdateSubnetIdsRequest.
        :rtype: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateSubnetIdsRequest.

        :param body: The body of this UpdateSubnetIdsRequest.
        :type body: :class:`huaweicloudsdkworkspace.v2.UpdateSubnetIdsRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubnetIdsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
